@@ -21,7 +21,10 @@
 
 const QString PROXY_ADDRESS_SETTING ("proxyAddress"); 
 const QString PROXY_PORT_SETTING ("proxyPort"); 
-const QString PROXY_ISDIRECT_SETTING ("proxyIsDirectConnection"); 
+const QString PROXY_TYPE_SETTING ("proxyType");
+const QString PROXY_USERNAME_SETTING ("proxyUsername");
+const QString PROXY_PASSWORD_SETTING ("proxyPassword");
+const QString PROXY_ISDIRECT_SETTING ("proxyIsDirectConnection");
 
 QSettings AppSettings::mSettings("Toastfreeware", "ConfClerk");
 
@@ -35,6 +38,24 @@ quint16 AppSettings::proxyPort()
     return mSettings.value(PROXY_PORT_SETTING).toUInt();
 }
 
+QNetworkProxy::ProxyType AppSettings::proxyType()
+{
+    bool ok;
+    int proxyType = mSettings.value(PROXY_TYPE_SETTING).toInt(&ok);
+    if (!ok || proxyType < 0 || proxyType > 5) return QNetworkProxy::DefaultProxy;
+    return QNetworkProxy::ProxyType(proxyType);
+}
+
+QString AppSettings::proxyUsername()
+{
+    return mSettings.value(PROXY_USERNAME_SETTING).toString();
+}
+
+QString AppSettings::proxyPassword()
+{
+    return mSettings.value(PROXY_PASSWORD_SETTING).toString();
+}
+
 bool AppSettings::isDirectConnection()
 {
     return mSettings.value(PROXY_ISDIRECT_SETTING).toBool();
@@ -50,6 +71,21 @@ void AppSettings::setProxyPort(const quint16 aPort)
     mSettings.setValue(PROXY_PORT_SETTING, aPort);
 }
 
+void AppSettings::setProxyType(QNetworkProxy::ProxyType aProxyType)
+{
+    mSettings.setValue(PROXY_TYPE_SETTING, aProxyType);
+}
+
+void AppSettings::setProxyUsername(const QString &aUsername)
+{
+    mSettings.setValue(PROXY_USERNAME_SETTING, aUsername);
+}
+
+void AppSettings::setProxyPassword(const QString &aPassword)
+{
+    mSettings.setValue(PROXY_PASSWORD_SETTING, aPassword);
+}
+
 void AppSettings::setDirectConnection(bool aDirectConnection)
 {
     mSettings.setValue(PROXY_ISDIRECT_SETTING, aDirectConnection);
