@@ -23,6 +23,7 @@
 
 #include <QString>
 #include <QSettings>
+#include <QNetworkProxy>
 
 class AppSettings
 {
@@ -35,10 +36,16 @@ class AppSettings
 
         static QString proxyAddress();
         static quint16 proxyPort();
+        static QNetworkProxy::ProxyType proxyType();
+        static QString proxyUsername();
+        static QString proxyPassword();
         static bool isDirectConnection();
 
         static void setProxyAddress(const QString &aAddress);
         static void setProxyPort(const quint16 aPort);
+        static void setProxyType(QNetworkProxy::ProxyType aProxyType);
+        static void setProxyUsername(const QString &aUsername);
+        static void setProxyPassword(const QString &aPassword);
         static void setDirectConnection(bool aDirectConnection);
         static int preEventAlarmSec() {return 60*15;} ///< seconds that alarm should ring before an event starts
 };
