@@ -20,7 +20,12 @@
 #ifndef SEARCHHEAD_H
 #define SEARCHHEAD_H
 
+#include "qglobal.h"
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#else
 #include <QtGui/QWidget>
+#endif
 #include <QDebug>
 #include "ui_searchhead.h"
 
