@@ -35,6 +35,11 @@ void SettingsDialog::loadDialogData()
     // deserialize dialog data
     address->setText(AppSettings::proxyAddress());
     port->setValue(AppSettings::proxyPort());
+    const QNetworkProxy::ProxyType proxyType = AppSettings::proxyType();
+    proxyTypeHTTP->setChecked(proxyType != QNetworkProxy::Socks5Proxy); // we enable QNetworkProxy::HttpProxy by default unless we have QNetworkProxy::Socks5Proxy
+    proxyTypeSOCKS5->setChecked(proxyType == QNetworkProxy::Socks5Proxy);
+    username->setText(AppSettings::proxyUsername());
+    password->setText(AppSettings::proxyPassword());
     directConnection->setChecked(AppSettings::isDirectConnection());
     proxyWidget->setDisabled(directConnection->isChecked());
 }
@@ -45,6 +50,9 @@ void SettingsDialog::saveDialogData()
     // serialize dialog data
     AppSettings::setProxyAddress(address->text());
     AppSettings::setProxyPort(port->value());
+    AppSettings::setProxyType(proxyTypeHTTP->isChecked() ? QNetworkProxy::HttpProxy : proxyTypeSOCKS5->isChecked() ? QNetworkProxy::Socks5Proxy : QNetworkProxy::DefaultProxy);
+    AppSettings::setProxyUsername(username->text());
+    AppSettings::setProxyPassword(password->text());
     AppSettings::setDirectConnection(directConnection->isChecked());
 }
 
