@@ -50,7 +50,7 @@ void UrlInputDialog::openFileClicked()
 
 void UrlInputDialog::textChanged(const QString& text)
 {
-    buttons->button(QDialogButtonBox::StandardButton::Open)->setEnabled(!text.isEmpty());
+    buttons->button(QDialogButtonBox::Open)->setEnabled(!text.isEmpty());
 }
 
 void UrlInputDialog::acceptClicked()
