@@ -52,8 +52,9 @@ private:
     // reinitialize list from database
     void reinit()
     {
+        beginResetModel();
         conferences = Conference::getAll();
-        reset();
+        endResetModel();
     }
 
     QList<Conference> conferences;
