@@ -237,7 +237,7 @@ void Delegate::paint(QPainter *painter, const QStyleOptionViewItem &option, cons
                 option.rect.x()+SPACER,
                 option.rect.y()+option.rect.height()-fmBig.descent());
         painter->setFont(fontBig);
-        painter->drawText(titlePointF,qVariantValue<QString>(index.data()));
+        painter->drawText(titlePointF,index.data().value<QString>());
     }
 
     painter->restore();
