@@ -20,7 +20,12 @@
 #ifndef DELEGATE_H
 #define DELEGATE_H
 
+#include "qglobal.h"
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#else
 #include <QtGui>
+#endif
 
 class Delegate : public QItemDelegate
 {
