@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2014 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2017 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -31,7 +31,7 @@ QSqlRecord const Event::sColumns = Event::toRecord(QList<QSqlField>()
     << QSqlField("xid_track", QVariant::Int)
     << QSqlField("type", QVariant::String)
     << QSqlField("language", QVariant::String)
-    << QSqlField("favourite", QVariant::Bool)
+    << QSqlField("favourite", QVariant::Int)
     << QSqlField("alarm", QVariant::Bool)
     << QSqlField("tag", QVariant::String)
     << QSqlField("title", QVariant::String)
@@ -90,7 +90,7 @@ QList<Event> Event::conflictEvents(int aEventId, int conferenceId) {
     query.prepare(selectQuery() + "WHERE xid_conference = :conf AND ( \
            ( start >= :s1 AND ( start + duration ) < :e1 ) \
         OR ( ( start + duration ) > :s2 AND start < :e2 ) ) \
-        AND favourite = 1 AND NOT id = :id ORDER BY start, duration");
+        AND favourite >= 1 AND NOT id = :id ORDER BY start, duration");
     query.bindValue(":conf", event.conferenceId());
     query.bindValue(":s1", convertToDb(event.start(), QVariant::DateTime));
     query.bindValue(":e1", convertToDb(event.start().toTime_t()+event.duration(), QVariant::DateTime));
@@ -116,7 +116,7 @@ QList<Event> Event::getFavByDate(const QDate& date, int conferenceId) {
     Conference conference = Conference::getById(conferenceId);
     QDateTime dayStart(date, conference.dayChangeTime(), Qt::UTC);
     QSqlQuery query;
-    query.prepare(selectQuery() + QString("WHERE xid_conference = :conf AND start >= :start AND start < :end AND favourite = 1 ORDER BY start, duration"));
+    query.prepare(selectQuery() + QString("WHERE xid_conference = :conf AND start >= :start AND start < :end AND favourite >= 1 ORDER BY start, duration"));
     query.bindValue(":conf", conferenceId);
     query.bindValue(":start", dayStart.toTime_t());
     query.bindValue(":end", dayStart.addDays(1).toTime_t());
@@ -192,12 +192,31 @@ QMap<QString,QString> Event::links()
     return mLinksList;
 }
 
-bool Event::hasTimeConflict() const
-{
-    if(!isFavourite()) // if it's not favourite, it can't have time-conflict
-        return false;
+Favourite Event::timeConflict() const {
+    if (favourite() == Favourite_no) // if it's not favourite, it can't have time-conflict
+        return Favourite_no;
 
-    return conflictEvents(id(),conferenceId()).count() > 0 ? true : false;
+    QList<Event> events = conflictEvents(id(),conferenceId());
+
+    // find "strongest" conflict
+    Favourite f = Favourite_no;
+    for (int i = 0; i != events.size(); ++i) {
+        switch (events[i].favourite()) {
+        case Favourite_strong: f = Favourite_strong; break;
+        case Favourite_weak: if (f == Favourite_no) f = Favourite_weak; break;
+        case Favourite_no: break;
+        }
+    }
+    return f;
+
+}
+
+void Event::cycleFavourite(bool back) {
+    switch (favourite()) {
+        case Favourite_no: setFavourite(back ? Favourite_weak : Favourite_strong); break;
+        case Favourite_strong: setFavourite(back ? Favourite_no : Favourite_weak); break;
+        case Favourite_weak: setFavourite(back ? Favourite_strong : Favourite_no); break;
+    }
 }
 
 void Event::setRoom(const QString &room)
