@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2014 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2017 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -35,6 +35,10 @@ class NoSuchEventException
 {
 };
 
+
+enum Favourite {Favourite_no=0, Favourite_weak=2, Favourite_strong=1};
+
+
 class Event : public OrmRecord<Event>
 {
 public:
@@ -59,9 +63,9 @@ public:
     int trackId() const { return value("xid_track").toInt(); }
     QString type() const { return value("type").toString(); }
     QString language() const { return value("language").toString(); }
-    bool isFavourite() const { return value("favourite").toBool(); }
+    Favourite favourite() const { return static_cast<Favourite>(value("favourite").toInt()); }
     bool hasAlarm() const { return value("alarm").toBool(); }
-    bool hasTimeConflict() const;
+    Favourite timeConflict() const;
     QString tag() const { return value("tag").toString(); }
     QString title() const { return value("title").toString(); }
     QString subtitle() const { return value("subtitle").toString(); }
@@ -81,7 +85,8 @@ public:
     void setTrackId(int trackId) { setValue("xid_track", trackId); }
     void setType(const QString & type) { setValue("type", type); }
     void setLanguage(const QString & language) { setValue("language", language); }
-    void setFavourite(bool favourite) { setValue("favourite", (int)((favourite))); }
+    void setFavourite(Favourite favourite) { setValue("favourite", (int) favourite); }
+    void cycleFavourite(bool back = false);
     void setHasAlarm(bool alarm) { setValue("alarm", (int)((alarm))); }
     void setTag(const QString& tag) { setValue("tag", tag); }
     void setTitle(const QString& title) { setValue("title", title); }
