@@ -44,6 +44,8 @@ void EventModel::Group::setTitle(const QList<Event>& mEvents) {
 // multiple of one hour.
 void EventModel::createTimeGroups()
 {
+    beginResetModel();
+
     mGroups.clear();
     mParents.clear();
     if (mEvents.empty()) return;
@@ -90,7 +92,7 @@ void EventModel::createTimeGroups()
     // the last group needs a title as well
     mGroups.last().setTitle(mEvents);
 
-    reset();
+    endResetModel();
 }
 
 void EventModel::createTrackGroups() {
@@ -174,7 +176,7 @@ QModelIndex EventModel::index(int row, int column, const QModelIndex& parent) co
 
     if (!parent.isValid())
     {
-        return createIndex(row, column, 0);
+        return createIndex(row, column);
     }
     else if (parent.internalId() == 0)
     {
@@ -199,7 +201,7 @@ QModelIndex EventModel::parent(const QModelIndex & index) const
 
         Event * event = static_cast<Event*>(index.internalPointer());
 
-        return createIndex(mParents[event->id()], 0, 0);
+        return createIndex(mParents[event->id()], 0);
     }
 
     return QModelIndex();
@@ -228,11 +230,11 @@ int EventModel::rowCount (const QModelIndex & parent) const
 
 void EventModel::clearModel()
 {
+    beginResetModel();
     mGroups.clear();
     mEvents.clear();
     mParents.clear();
-
-    reset();
+    endResetModel();
 }
 
 
