@@ -28,8 +28,8 @@
 class SqlEngine : public QObject {
     Q_OBJECT
     public:
-        const QString DATE_FORMAT = "yyyy-MM-dd";
-        const QString TIME_FORMAT = "hh:mm";
+        const QString DATE_FORMAT; // "yyyy-MM-dd"
+        const QString TIME_FORMAT; // "hh:mm"
 
         QString dbFilename; ///< database filename including path
         QSqlDatabase db; ///< this may be private one day...
@@ -85,9 +85,9 @@ class SqlEngine : public QObject {
 
 class TransactionRaii {
     SqlEngine& sqlEngine;
-    bool committed = false;
+    bool committed;
 public:
-    TransactionRaii(SqlEngine& sqlEngine): sqlEngine(sqlEngine) {
+    TransactionRaii(SqlEngine& sqlEngine): sqlEngine(sqlEngine), committed(false) {
         sqlEngine.beginTransaction();
     }
 
